summaryrefslogtreecommitdiff
path: root/src/channels.c
diff options
context:
space:
mode:
authorAdam- <Adam-@5417fbe8-f217-4b02-8779-1006273d7864>2010-02-06 19:27:10 +0000
committerAdam- <Adam-@5417fbe8-f217-4b02-8779-1006273d7864>2010-02-06 19:27:10 +0000
commit87b62c433d3abdf92b8d55987f76553d9422c3d2 (patch)
treeeccd3a0cc240a747029a85ed0c47456ccbc60da9 /src/channels.c
parentde99f898941afa524bde2ac2442b54a673750c5f (diff)
Remove protectbotserv option from modes, just use options:botmodes instead
git-svn-id: http://anope.svn.sourceforge.net/svnroot/anope/trunk@2782 5417fbe8-f217-4b02-8779-1006273d7864
Diffstat (limited to 'src/channels.c')
-rw-r--r--src/channels.c12
1 files changed, 10 insertions, 2 deletions
diff --git a/src/channels.c b/src/channels.c
index 4f764b8fc..69843d1da 100644
--- a/src/channels.c
+++ b/src/channels.c
@@ -445,9 +445,17 @@ void Channel::RemoveModeInternal(ChannelMode *cm, const std::string &param, bool
return;
}
- /* We don't track bots */
- if (findbot(param))
+ /* Reset modes on bots if we're supposed to */
+ BotInfo *bi = findbot(param);
+ if (bi)
+ {
+ if (std::find(BotModes.begin(), BotModes.end(), cm) != BotModes.end())
+ {
+ this->SetMode(bi, cm, bi->nick);
+ }
+ /* We don't track bots */
return;
+ }
User *u = finduser(param);
if (!u)